===========
 nti.intid
===========

.. image:: https://travis-ci.org/NextThought/nti.intid.svg?branch=master
    :target: https://travis-ci.org/NextThought/nti.intid

.. image:: https://coveralls.io/repos/github/NextThought/nti.intid/badge.svg?branch=master
    :target: https://coveralls.io/github/NextThought/nti.intid?branch=master

.. image:: https://readthedocs.org/projects/ntiintid/badge/?version=latest
   :target: https://ntiintid.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

Extensions for Zope3's intid concept.

See `zope.intid <https://pypi.org/project/zope.intid/>`_ and `zc.intid
<https://pypi.org/project/zc.intid/>`_ for information on the basics.
